from ai_dashboard.tabs.data_report.data_report import *
from ai_dashboard.tabs.data_report.markdown import *
from ai_dashboard.tabs.data_report import blocks
